@@ -210,6 +210,10 @@ case "$switch" in
      echo -n $msg_press_enter_to_continue
      read
 
+     # Before we run drblpush, we have to remove the services we put only for DRBL live server when creating drbl live. This will avoide those to be copied to SSI template tarball. Since these services are one-time use only for server during booting.
+     rm -f /etc/rcS.d/*kbd-conf
+     rm -f /etc/rcS.d/*Forcevideo-drbl-live 
+
      # load $client_no_per_NIC and $autologin_passwd_opt for later use
      . $drbl_setup_path/files/ocs/live-hook/ocs-live.conf
 
